@@ -1,7 +1,7 @@
 /* This file is part of the KDE project
    Copyright (C) 2004 Cedric Pasteur <cedric.pasteur@free.fr>
    Copyright (C) 2004 Alexander Dymo <cloudtemple@mskat.net>
-   Copyright (C) 2004-2015 Jarosław Staniek <staniek@kde.org>
+   Copyright (C) 2004-2016 Jarosław Staniek <staniek@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -29,26 +29,6 @@
 
 #include "kpropertycore_export.h"
 
-/*! \brief Namespace for a set of classes implementing generic properties framework.
-
- Main classes of this framework are:
-  - Property, representing a single property with its own type and value
-  - Set, a set of properties
-  - Editor, a widget for displaying and editing properties provided by a Set object.
-    Every property has its own row displayed using EditorItem object, within Editor widget.
-    Widget class provides editing feature for EditorItem objects if a user selects a given item.
-
- KProperty framework also supports adding composed and property types
- and custom property editor types.
-
- Take a look at the test application, available in the test/ directory
- to see example uses of the framework.
-
- @author Cedric Pasteur <cedric.pasteur@free.fr>
- @author Alexander Dymo <cloudtemple@mskat.net>
- @author Jarosław Staniek <staniek@kde.org>
-*/
-
 class KComposedPropertyInterface;
 class KPropertySet;
 
@@ -71,62 +51,52 @@ public:
      so the first key element is associated with first element from
      the 'names' list, and so on. */
     QList<QVariant> keys;
-//   QStringList keys;
 
 //! @todo what about using QValueList<QVariant> here too?
     /*! The list of translated names that will be visible on the screen.
      First value is referenced by first key, and so on. */
     QStringList names;
-
-//unused for now   /*! True (the default), if the list has fixed number of possible
-//unused for now    items (keys). If this is false, user can add or enter own values. */
-//unused for now   bool fixed;
 };
 
 /*! \brief The base class representing a single property
 
-  It can hold a property of any type supported by QVariant. You can also create you own property
-  types (see Using Custom Properties in Factory doc). As a consequence, do not subclass Property,
-  use \ref KComposedPropertyInterface instead. \n
-  Each property stores old value to allow undo. It has a name (a QByteArray), a caption
-  (user-visible translated name shown in Editor) and a description (also translated). \n
-  It also supports setting arbitrary number of options (of type option=value).
-  See Editor for a list of options, and their meaning.
+  KProperty object can hold a property of given type supported by QVariant. Properties of custom types
+  can be also created, see using KPropertyFactory. Composed or custom properties
+  are not created using subclassing of KProperty but using @ref KComposedPropertyInterface.
 
-  \code
-  // To create a property
-  property = Property(name, value, caption, description); // name is a QByteArray,
-  // value is whatever type QVariant supports
+  Each property stores old value to allows undoing that reverts the value to the old one.
+  Property has a non-empty name (a QByteArray), a caption that is user-visible translated string
+  displayed in property editor. Description is a translatable string that can be specified too
+  in order to further explain meaning of the property.
 
-  // To create a valueFromList property (matching strings with strings)
-  QStringList keys, strings;
+  Propery also supports setting arbitrary number of options using KProperty::setOption() that allow
+  to customize look or behavior of the property in the editor.
+
+  @code
+  // Creating a simple property:
+  KProperty *property = new KProperty(name, value, caption, description);
+  // name is a QByteArray, value is whatever type QVariant supports
+
+  // Creating a valueFromList property matching keys with names:
+  QStringList keys, names;
   keys << "one" << "two" << "three"; // possible values of the property
-  // Strings (possibly translated) shown in the editor instead of the values
-  strings << tr("One") << tr("Two") << tr("Three");
-  property = Property(name, keys, strings, "two", caption);
+  // Names (possibly translated) shown in the editor instead of the keys
+  names << tr("One") << tr("Two") << tr("Three");
+  property = new KProperty(name, keys, names, "two", caption);
 
-  // To create a valueFromList property (matching strings with QVariant)
-  QValueList<QVariant> keys2;
-  keys2.append(1);
-  keys2.append(2);
-  keys2.append(3);
-  Property::ListData listData(keys2, strings);
-  m_set->addProperty(new Property("List2", listData, "otheritem", "List2"), group);
-  \endcode
+  // Creating a valueFromList property matching QVariant keys with names:
+  QValueList<QVariant> variantKeys;
+  variantKeys << 1 << 2 << 3;
+  KPropertyListData *listData = new KPropertyListData(variantKeys, names);
+  propertySet->addProperty(new KProperty("List", listData, "otheritem", "List"));
+  @endcode
 
-  Note that you need to use QVariant(bool, int) to create a boolean property value.
-  See QVariant docs for more details.
-
-  Sometimes, for longer property captions or these with more words, e.g. "Allow Zero Size",
-  its usable to provide newline characters, e.g. "Allow Zero\nSize".
-  If caption argument of the constructors contains newline characters,
-  caption() will return this text with substituted these characters with spaces.
-  In such cases, captionForDisplaying() is used to get the original caption text usable
-  (with newline, if any) for displaying within a property editor.
-
-  \author Cedric Pasteur <cedric.pasteur@free.fr>
-  \author Alexander Dymo <cloudtemple@mskat.net>
-  \author Jarosław Staniek <staniek@kde.org>
+  @note Sometimes it makes sense to split property captions that have with more words to multiple lines
+  using a newline character, e.g. "Allow Zero Size" to "Allow Zero\nSize".
+  This is suitable especially for the needs of property editor which can offer only limited area.
+  The text of property caption containing newline characters is available in its original form using
+  KProperty::captionForDisplaying(). KProperty::caption() returns modified caption text in which
+  the newline characters are substituted with spaces and any trailing and leading whitespace is removed.
 */
 class KPROPERTYCORE_EXPORT KProperty
 {
@@ -192,20 +162,6 @@ public:
         DirectoryURL                  /**<url of a directory*/,
         LineStyle                     /**<line style*/,
 
-        // Child property types
-    /*    Size_Height = 3001,
-        Size_Width,
-        Point_X,
-        Point_Y,
-        Rect_X,
-        Rect_Y,
-        Rect_Width,
-        Rect_Height,
-        SizePolicy_HorizontalPolicy,
-        SizePolicy_VerticalPolicy,
-        SizePolicy_HorizontalStretch,
-        SizePolicy_VerticalStretch,*/
-
         UserDefined = 4000            /**<plugin defined properties should start here*/
     };
 
@@ -216,23 +172,22 @@ public:
      If \a caption contains newline characters, caption() will return \a caption with substituted
      these with spaces. captionForDisplaying() is used to get original caption text usable
      (with newline, if any) for displaying within a property editor. */
-    explicit
-    KProperty(const QByteArray &name, const QVariant &value = QVariant(),
+    explicit KProperty(const QByteArray &name, const QVariant &value = QVariant(),
              const QString &caption = QString(), const QString &description = QString(),
-             int type = Auto, KProperty* parent = 0);
+             int type = Auto, KProperty* parent = nullptr);
 
     /*! Constructs property of \ref ValueFromList type. */
     KProperty(const QByteArray &name, const QStringList &keys, const QStringList &strings,
              const QVariant &value = QVariant(),
              const QString &caption = QString(), const QString &description = QString(),
-             int type = ValueFromList, KProperty* parent = 0);
+             int type = ValueFromList, KProperty* parent = nullptr);
 
     /*! Constructs property of \ref ValueFromList type.
      This is overload of the above ctor added for convenience. */
     KProperty(const QByteArray &name, KPropertyListData* listData,
              const QVariant &value = QVariant(),
              const QString &caption = QString(), const QString &description = QString(),
-             int type = ValueFromList, KProperty* parent = 0);
+             int type = ValueFromList, KProperty* parent = nullptr);
 
     /*! Constructs a deep copy of \a prop property. */
     KProperty(const KProperty &prop);
@@ -254,8 +209,8 @@ public:
     QString captionForDisplaying() const;
 
     /*! Sets the name of the property. If the caption contains newline characters,
-     these are replaced by spaces. You can use captionForDisplaying()
-     to access the original caption text you passed here.*/
+     these are replaced by spaces. captionForDisplaying() can be used to access the original caption
+     text passed here.*/
     void setCaption(const QString &caption);
 
     /*! \return the description of the property.*/
@@ -278,7 +233,8 @@ public:
 
     void childValueChanged(KProperty *child, const QVariant &value, bool rememberOldValue);
 
-    /*! Sets the value of the property.*/
+    //! Sets value of the property to @a value
+    //! @todo 4.0 BCI: replace with bool setValue(QVariant, ValueOptions)
     void setValue(const QVariant &value, bool rememberOldValue = true, bool useComposedProperty = true);
 
     /*! Resets the value of the property to the old value.
@@ -331,21 +287,22 @@ public:
     //! Clears "modified" flag, so isModified() will return false.
     void clearModifiedFlag();
 
-    /*! \return true if the property is read-only.
-     The property can be read-write but still not editable because the property
-     set containing it may be set to read-only.
-     By default the property is read-write.
-     See Set::isReadOnly() for more details. */
+    /*! \return true if the property is read-only when used in a property editor.
+     @c false by default.
+     The property can be read-write but still not editable for the user if the parent property set's
+     read-only flag is set.
+     @see KPropertySet::isReadOnly() */
     bool isReadOnly() const;
 
     /*! Sets this property to be read-only.
      @see isReadOnly() */
     void setReadOnly(bool readOnly);
 
-    /*! \return true if the property is visible.*/
+    /*! \return true if the property is visible.
+     Only visible properties are displayed by the property editor view. */
     bool isVisible() const;
 
-    /*! Set the visibility.*/
+    /*! Sets the visibility flag.*/
     void setVisible(bool visible);
 
     /*! \return true if the property can be saved to a stream, xml, etc.
@@ -356,31 +313,72 @@ public:
     /*! Sets "storable" flag for this property. @see isStorable() */
     void setStorable(bool storable);
 
-    /*! \return 1 if the property should be synced automatically in Property Editor
+    /*! \return 1 if the property should be synced automatically in the property editor
     as soon as editor contents change (e.g. when the user types text).
     If autoSync() == 0, property value will be updated when the user presses Enter
     or when another editor gets the focus.
-    Property follows Property Editor's global rule if autoSync() !=0 and !=1 (the default).
+    Property follows property editor's global rule if autoSync() !=0 and !=1 (the default).
     */
     int autoSync() const;
 
-    /*! if \a sync is 1, the property will be synced automatically in the Property Editor
+    /*! If \a sync is 1, the property will be synced automatically in the property editor
     as soon as editor's contents change (e.g. when the user types text).
     If \a sync is 0, property value will be updated when the user presses
     Enter or when another editor gets the focus.
-    Property follows Property Editor's global rule if sync !=0 and !=1 (the default).
+    Property follows property editor's global rule if sync !=0 and !=1 (the default).
     */
     void setAutoSync(int sync);
 
     /*! Sets value \a val for option \a name.
-     Options are used to describe additional details for property behaviour,
-     e.g. within Editor. See Editor ctor documentation for
-     the list of supported options.
-    */
+     Options are used to override default settings of individual properties.
+     This is most visible in property editor widget.
+
+    Currently supported options are:
+    <ul><li> min: integer value describing minimum value for properties of integer and
+             double types. The default is 0.</li>
+    <li> minValueText: user-visible translated string to be displayed in editor for integer
+         type when minimum is set for the property.
+         @see QAbstractSpinBox::specialValueText</li>
+    <li> max: integer describing minimum value for properties of integer type. Default is 0xffff.</li>
+    <li> precision: integer value >= 0 describing the number of decimals after the decimal
+         point for double type. Default value is 2.
+         @see QDoubleSpinBox::decimals</li>
+    <li> step: double value > 0.0 describing the size of the step that is taken when
+         the user hits the up or down button of editor for double type. Default value is 0.01.
+         @see QDoubleSpinBox::singleStep</li>
+    <li> 3State: boolean value used for boolean type; if @c true, the editor becomes a combobox
+         (instead of checkable button) and accepts the third "null" state.</li>
+    <li> yesName: user-visible translated string used for boolean type (both 2- and 3-state)
+         to visually represent the "true" value. If not present, tr("Yes") is used.</li>
+    <li> noName: user-visible translated string used for boolean type (both 2- and 3-state)
+         to visually represent the "false" value. If not present, tr("No") is used.</li>
+    <li> 3rdStateName: user-visible translated string used for boolean type (both 2- and 3-state)
+         to visually represent the third "null" value. If not present, tr("None") is used.</li>
+    <li> nullName: user-visible translated string used for boolean type to display the "null"
+         value, if and only if the property accepts two states (i.e. when "3State" option
+         is @c false). If the "nullName" option is not set, null values are displayed as
+         @c false.</li>
+    <li> extraValueAllowed: boolean value, if @c true the user is able to manually add extra
+         values to a combobox.</li>
+    <li> fileMode: string value that describes what objects may select in the file dialog
+         of the url editor:
+         <ul>
+         <li>"dirsOnly": only support and display directories;
+             @see QFileDialog::ShowDirsOnly QFileDialog::Directory</li>
+         <li>"existingFile": only allow to select one existing file;
+             @see QFileDialog::ExistingFile</li>
+         <li>Any other value: any file is supported, whether it exists or not
+             @see QFileDialog::AnyFile</li>
+         </ul>
+         </li>
+    <li> confirmOverwrites: boolean value, if @c true, user will be asked for confirmation
+         of file overwriting in the url editor. @c false by default.
+         @note The line edit does not validate the content.</li>
+    </ul>*/
     void setOption(const char* name, const QVariant& val);
 
-    /*! \return a value for option \a name or null value if there is no such option set.
-     If there is no such value, @a defaultValue is returned. */
+    /*! \return a value for option \a name or @a defaultValue value if there is no such option set.
+     @see setOption */
     QVariant option(const char* name, const QVariant& defaultValue = QVariant()) const;
 
     /*! \return true if at least one option is defined for this property. */
@@ -397,7 +395,7 @@ public:
 
 #if 0
     /*! \return a key used for sorting.
-     Usually its set by Set::addProperty() and Property::addChild() to a unique value,
+     Usually its set by KPropertySet::addProperty() and KProperty::addChild() to a unique value,
      so that this property can be sorted in a property editor in original order.
      \see EditorItem::compare() */
     int sortingKey() const;
@@ -422,15 +420,14 @@ protected:
     /*! Adds related property for this property. */
     void addRelatedProperty(KProperty *property);
 
-    /*! This method emits the \a Set::propertyChanged() signal for all
-    sets this property is registered in. The \a value() method above
-    calls this method of the value changed. */
+    /*! This method emits the \a KPropertySet::propertyChanged() signal.
+    KProperty::setValue() calls this method if the value has been changed. */
     void emitPropertyChanged();
 
-    /*! Outputs debug string for this property. */
+    /*! Outputs debug string for this property to the standard debug output. */
     void debug() const;
 
-    /*! For operator <<. */
+    /*! Used by debug operator <<. */
     QMap<QByteArray, QVariant> options() const;
 
     //! @internal
