@@ -31,7 +31,7 @@ public:
     explicit Private(KPropertySet *set) :
             q(set),
             readOnly(false),
-            informAboutClearing(0),
+            informAboutClearing(nullptr),
             m_visiblePropertiesCount(0)
     {}
 
@@ -48,7 +48,7 @@ public:
         KProperty *p = property(name);
         if (p)
             return *p;
-        nonConstNull.setName(0); //to ensure returned property is null
+        nonConstNull.setName(nullptr); //to ensure returned property is null
         kprWarning() << "PROPERTY" << name << "NOT FOUND";
         return nonConstNull;
     }
@@ -90,24 +90,26 @@ public:
             return;
 
         if (!list.removeOne(property)) {
-            kprDebug() << "Set does not contain property" << property;
+            kprDebug() << "The property set does not contain property" << property;
             return;
         }
-        KProperty *p = hash.take(property->name());
-        q->removeFromGroup(p);
-        if (p->isVisible()) {
-            m_visiblePropertiesCount--;
-        }
-        if (ownProperty) {
-            emit q->aboutToDeleteProperty(*q, *p);
-            delete p;
+        KProperty *p = hash.take(property->name().toLower());
+        if (p) {
+            q->removeFromGroup(p);
+            if (p->isVisible()) {
+                m_visiblePropertiesCount--;
+            }
+            if (ownProperty) {
+                emit q->aboutToDeleteProperty(*q, *p);
+                delete p;
+            }
         }
     }
 
     void clear() {
         if (informAboutClearing)
             *informAboutClearing = true;
-        informAboutClearing = 0;
+        informAboutClearing = nullptr;
         emit q->aboutToBeCleared();
         m_visiblePropertiesCount = 0;
         qDeleteAll(propertiesOfGroup);
@@ -137,7 +139,7 @@ public:
         groupForProperties.remove(property);
     }
 
-    // Copy all attributes except complex ones
+    //! Copy all attributes except complex ones
     void copyAttributesFrom(const Private &other)
     {
         KPropertySet *origSet = q;
@@ -149,10 +151,10 @@ public:
         propertiesOfGroup.clear();
         groupForProperties.clear();
         m_visiblePropertiesCount = 0;
-        informAboutClearing = 0;
+        informAboutClearing = nullptr;
     }
 
-    // Copy all properties from the other set
+    //! Copy all properties from the other set
     void copyPropertiesFrom(
         const QList<KProperty*>::ConstIterator& constBegin,
         const QList<KProperty*>::ConstIterator& constEnd, const KPropertySet & set)
@@ -163,7 +165,7 @@ public:
 #if 0
                         ,
                         false /* don't updateSortingKey, because the key is already
-                                 set in Property copy ctor.*/
+                                 set in KProperty copy ctor.*/
 #endif
                        );
         }
@@ -191,20 +193,20 @@ public:
     bool readOnly;
     QByteArray prevSelection;
 
-    //! Used in Set::informAboutClearing(Property*) to declare that the property wants
+    //! Used in KPropertySet::informAboutClearing(bool&) to declare that the property wants
     //! to be informed that the set has been cleared (all properties are deleted)
     bool* informAboutClearing;
 
     mutable KProperty nonConstNull;
 
 private:
-    //! a list of properties, preserving their order, owner of Property objects
+    //! A list of properties, preserving their order, owner of KProperty objects
     QList<KProperty*> list;
-    //! a hash of properties in form name -> property
+    //! A hash of properties in form name -> property
     QHash<QByteArray, KProperty*> hash;
     QHash<KProperty*, QByteArray> groupForProperties;
-    uint m_visiblePropertiesCount; //! cache for optimization,
-                                   //! used by @ref bool Set::hasVisibleProperties()
+    uint m_visiblePropertiesCount; //!< Cache for optimization,
+                                   //!< used by @ref bool KPropertySet::hasVisibleProperties()
 };
 
 //////////////////////////////////////////////
@@ -233,7 +235,7 @@ KPropertySetIterator::KPropertySetIterator(const KPropertySet &set)
     : m_set(&set)
     , m_iterator( set.d->listConstIterator() )
     , m_end( set.d->listConstEnd() )
-    , m_selector( 0 )
+    , m_selector( nullptr )
     , m_order(KPropertySetIterator::InsertionOrder)
 {
 }
@@ -335,7 +337,7 @@ KPropertySet::KPropertySet(QObject *parent)
 
 
 KPropertySet::KPropertySet(const KPropertySet &set)
-        : QObject(0 /* implicit sharing the parent is dangerous */)
+        : QObject(nullptr /* implicit sharing the parent is dangerous */)
         , d(new KPropertySet::Private(this))
 {
     setObjectName(set.objectName());
@@ -343,7 +345,7 @@ KPropertySet::KPropertySet(const KPropertySet &set)
 }
 
 KPropertySet::KPropertySet(bool propertyOwner)
-        : QObject(0)
+        : QObject(nullptr)
         , d(new KPropertySet::Private(this))
 {
     d->ownProperty = propertyOwner;
@@ -525,7 +527,10 @@ KPropertySet::isReadOnly() const
 void
 KPropertySet::setReadOnly(bool readOnly)
 {
-    d->readOnly = readOnly;
+    if (d->readOnly != readOnly) {
+        d->readOnly = readOnly;
+        emit readOnlyFlagChanged();
+    }
 }
 
 bool
