@@ -1,7 +1,7 @@
 /* This file is part of the KDE project
    Copyright (C) 2004 Cedric Pasteur <cedric.pasteur@free.fr>
    Copyright (C) 2004 Alexander Dymo <cloudtemple@mskat.net>
-   Copyright (C) 2004-2016 Jarosław Staniek <staniek@kde.org>
+   Copyright (C) 2004-2017 Jarosław Staniek <staniek@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -96,14 +96,14 @@ public:
         m_isOpen = set;
     }
 
-    virtual QSize sizeHint() const {
+    QSize sizeHint() const override {
         QSize s(QWidget::sizeHint());
         s.setHeight(fontMetrics().height()*2);
         return s;
     }
 
 protected:
-    virtual void paintEvent(QPaintEvent *) {
+    void paintEvent(QPaintEvent *) override {
         QRect r(rect());
         QPainter p(this);
         QStyleOptionHeader option;
@@ -128,7 +128,7 @@ protected:
         }
     }
 
-    virtual bool event(QEvent * e) {
+    bool event(QEvent * e) override {
         if (e->type() == QEvent::MouseButtonPress || e->type() == QEvent::MouseButtonRelease) {
             QMouseEvent* me = static_cast<QMouseEvent*>(e);
             if (me->button() == Qt::LeftButton) {
@@ -238,7 +238,7 @@ QColor KPropertyUtils::contrastColor(const QColor& c)
 QColor KPropertyUtils::gridLineColor(const QWidget *widget)
 {
     Q_ASSERT(widget);
-    KPropertyEditorView *view = 0;
+    KPropertyEditorView *view = nullptr;
     if (widget->parentWidget()) {
         view = qobject_cast<KPropertyEditorView*>(widget->parentWidget()->parentWidget());
     }
@@ -253,3 +253,14 @@ KPROPERTYWIDGETS_EXPORT KProperty* KPropertyUtils::propertyForIndex(const QModel
             = qobject_cast<const KPropertyEditorDataModel*>(index.model());
     return editorModel ? editorModel->propertyForIndex(index) : nullptr;
 }
+
+bool KPropertyUtils::shouldUseNativeDialogs()
+{
+#if defined Q_OS_UNIX && !defined Q_OS_MACOS
+    const QString xdgSessionDesktop = QString::fromLatin1(qgetenv("XDG_CURRENT_DESKTOP").trimmed());
+    return xdgSessionDesktop.isEmpty()
+        && 0 == xdgSessionDesktop.compare(QStringLiteral("KDE"), Qt::CaseInsensitive);
+#else
+    return true;
+#endif
+}
